==> pfe_0.32.30.orig.tar.gz: pfe-0.32.30.orig/pfe/double-mix.h <==
#ifndef _PFE_DOUBLE_MIX_H
#define _PFE_DOUBLE_MIX_H 1002653674
/* generated 2001-1009-2054 ../../../pfe/../mk/Make-H.pl ../../../pfe/double-mix.c */

#include <pfe/incl-mix.h>

/** 
 * -- miscellaneous useful extra words for DOUBLE-EXT
 *
 *  Copyright (C) Tektronix, Inc. 1998 - 2001. All rights reserved.
 *
 *  @see     GNU LGPL
 *  @author  Tektronix CTE              @(#) %derived_by: guidod %
 *  @version %version:  %
 *    (%date_modified:  %)
 *
 *  @description
 *      Compatiblity with former standards, miscellaneous useful words.
 *      ... for DOUBLE-EXT  (which is almost complete... just almost)
 */

#ifdef __cplusplus
extern "C" {
#endif




/** 2ROT ( d1,d1 d2,d2 d3,d3 -- d2,d2 d3,d3 d1,d1 )
 * the double-cell => ROT operation.
 * actively moves six cells, i.e.
   ( x1 x2 x3 x4 x5 x6 -- x3 x4 x5 x6 x1 x2 )
 */
extern P4_CODE (p4_two_rot);

/** DU< ( d1,d1 d2,d2 -- flag )
 * the double-cell unsigned-is-less operation ( =>"U<" )
 */
extern P4_CODE (p4_d_u_less);

/** LITERAL, ( value -- )
 * take the value from stack (or cs-stack) and compile a runtime-code and
 * the value as for => LITERAL ... this word is never state-smart, it
 * is not immediate, and has therefore no complications with => POSTPONE
 * (compare also with =>"COMPILE," to make a call-stub with an exectoken)
 */
extern P4_CODE (p4_literal_comma);

/** 2LITERAL, ( x1,x2 -- )
 * take the double-value from stack (or cs-stack) and compile a runtime-code 
 * and the value as for => 2LITERAL ... this word is never state-smart, it
 * is not immediate, and has therefore no complications with => POSTPONE
 * (compare also with =>"COMPILE," to make a call-stub with an exectoken)
 */
extern P4_CODE (p4_two_literal_comma);

#ifdef __cplusplus
} /* extern "C" */
#endif


#endif

==> pfe_0.33.34.orig.tar.gz: pfe-0.33.34.orig/pfe/double-mix.h <==
#ifndef _PFE_DOUBLE_MIX_H
#define _PFE_DOUBLE_MIX_H 1063198927
/* generated 2003-0910-1502 ../../../pfe/../mk/Make-H.pl ../../../pfe/double-mix.c */

#include <pfe/pfe-mix.h>

/** 
 * -- miscellaneous useful extra words for DOUBLE-EXT
 *
 *  Copyright (C) Tektronix, Inc. 1998 - 2001. All rights reserved.
 *
 *  @see     GNU LGPL
 *  @author  Tektronix CTE              @(#) %derived_by: guidod %
 *  @version %version:  33.11 %
 *    (%date_modified:  Fri Mar 14 14:44:22 2003 %)
 *
 *  @description
 *      Compatiblity with former standards, miscellaneous useful words.
 *      ... for DOUBLE-EXT  (which is almost complete... just almost)
 */

#ifdef __cplusplus
extern "C" {
#endif




/** 2ROT ( d1,d1 d2,d2 d3,d3 -- d2,d2 d3,d3 d1,d1 )
 * the double-cell => ROT operation.
 * actively moves six cells, i.e.
   ( x1 x2 x3 x4 x5 x6 -- x3 x4 x5 x6 x1 x2 )
 */
extern P4_CODE (p4_two_rot);

/** DU< ( d1,d1 d2,d2 -- flag )
 * the double-cell unsigned-is-less operation ( =>"U<" )
 */
extern P4_CODE (p4_d_u_less);

/** LITERAL, ( value -- )
 * take the value from stack (or cs-stack) and compile a runtime-code and
 * the value as for => LITERAL ... this word is never state-smart, it
 * is not immediate, and has therefore no complications with => POSTPONE
 * (compare also with =>"COMPILE," to make a call-stub with an exectoken)
 */
extern P4_CODE (p4_literal_comma);

/** 2LITERAL, ( x1,x2 -- )
 * take the double-value from stack (or cs-stack) and compile a runtime-code 
 * and the value as for => 2LITERAL ... this word is never state-smart, it
 * is not immediate, and has therefore no complications with => POSTPONE
 * (compare also with =>"COMPILE," to make a call-stub with an exectoken)
 */
extern P4_CODE (p4_two_literal_comma);

/** DCELLS ( x -- x' )
 * computes the number of address units for the specified number 
 * of double-cells
 : DCELLS CELLS 2* ;
 */
extern P4_CODE (p4_dcells);

#ifdef __cplusplus
} /* extern "C" */
#endif


#endif
